@@ -49,8 +49,6 @@ REQUIRED_DOCKER_SECTIONS = ['service_name', 'docker_config', 'puppet_config',
 OPTIONAL_DOCKER_SECTIONS = ['container_puppet_tasks', 'upgrade_tasks',
                             'deploy_steps_tasks',
                             'pre_upgrade_rolling_tasks',
-                            'fast_forward_upgrade_tasks',
-                            'fast_forward_post_upgrade_tasks',
                             'post_upgrade_tasks', 'update_tasks',
                             'post_update_tasks', 'service_config_settings',
                             'host_prep_tasks', 'metadata_settings',
@@ -62,8 +60,6 @@ OPTIONAL_DOCKER_SECTIONS = ['container_puppet_tasks', 'upgrade_tasks',
                             'external_update_tasks', 'external_upgrade_tasks']
 # ansible tasks cannot be an empty dict or ansible is unhappy
 ANSIBLE_TASKS_SECTIONS = ['upgrade_tasks', 'pre_upgrade_rolling_tasks',
-                          'fast_forward_upgrade_tasks',
-                          'fast_forward_post_upgrade_tasks',
                           'post_upgrade_tasks', 'update_tasks',
                           'post_update_tasks', 'host_prep_tasks',
                           'external_deploy_tasks',
@@ -117,6 +113,7 @@ PARAMETER_DEFINITION_EXCLUSIONS = {
     'KeystoneAdminErrorLoggingSource': ['default'],
     'KeystoneMainAcccessLoggingSource': ['default'],
     'KeystoneMainErrorLoggingSource': ['default'],
+    'LibvirtVncCACert': ['description'],
     'NeutronApiLoggingSource': ['default'],
     'NeutronDhcpAgentLoggingSource': ['default'],
     'NeutronL3AgentLoggingSource': ['default'],
@@ -245,9 +242,6 @@ WORKFLOW_TASKS_EXCLUSIONS = [
     './deployment/ceph-ansible/ceph-base.yaml',
     './deployment/ceph-ansible/ceph-mon.yaml',
     './deployment/ceph-ansible/ceph-mgr.yaml',
-    './docker/services/skydive/skydive-base.yaml',
-    './docker/services/skydive/skydive-agent.yaml',
-    './docker/services/skydive/skydive-analyzer.yaml',
 ]
 
 
@@ -741,16 +735,6 @@ def validate_docker_service(filename, tpl):
                 print('ERROR: upgrade_tasks validation failed')
                 return 1
 
-        if 'fast_forward_upgrade_tasks' in role_data and role_data['fast_forward_upgrade_tasks']:
-            if validate_upgrade_tasks(role_data['fast_forward_upgrade_tasks']):
-                print('ERROR: fast_forward_upgrade_tasks validation failed')
-                return 1
-
-        if 'fast_forward_post_upgrade_tasks' in role_data and role_data['fast_forward_post_upgrade_tasks']:
-            if validate_upgrade_tasks(role_data['fast_forward_post_upgrade_tasks']):
-                print('ERROR: fast_forward_post_upgrade_tasks validation failed')
-                return 1
-
     if 'parameters' in tpl:
         for param in required_params:
             if param not in tpl['parameters']:
@@ -806,16 +790,6 @@ def validate_service(filename, tpl):
                 print('ERROR: upgrade_tasks validation failed')
                 return 1
 
-        if 'fast_forward_upgrade_tasks' in role_data and role_data['fast_forward_upgrade_tasks']:
-            if validate_upgrade_tasks(role_data['fast_forward_upgrade_tasks']):
-                print('ERROR: fast_forward_upgrade_tasks validation failed')
-                return 1
-
-        if 'fast_forward_post_upgrade_tasks' in role_data and role_data['fast_forward_post_upgrade_tasks']:
-            if validate_upgrade_tasks(role_data['fast_forward_post_upgrade_tasks']):
-                print('ERROR: fast_forward_post_upgrade_tasks validation failed')
-                return 1
-
     if 'parameters' in tpl:
         for param in required_params:
             if param not in tpl['parameters']:
@@ -962,6 +936,10 @@ def validate_service_hiera_interpol(f, tpl):
             if enter_lists and path[-1] != 0 and path[-2] != 'get_param':
                 continue
 
+            # Omit if it is not a hiera config setting
+            if path[1] in ['kolla_config']:
+                continue
+
             path_str = ';'.join(str(x) for x in path)
             # NOTE(bogdando): Omit foo_network keys looking like a network
             # name. The only exception is allow anything under
